@@ -77,8 +77,8 @@ import qualified Data.Yaml as Y
 import GHC.Generics
 import System.Directory (getHomeDirectory)
 
-import Options.Applicative.Builder (argument, auto, command, footerDoc, headerDoc, help, helpDoc, info, long, metavar, option, prefs, progDesc, showDefault, showHelpOnError, str, strOption, subparser, switch, value)
-import Options.Applicative.Extra (customExecParser, helper)
+import Options.Applicative.Builder (argument, auto, command, footerDoc, headerDoc, help, helpDoc, info, long, metavar, option, prefs, progDesc, showDefault, showHelpOnError, str, strOption, switch, value)
+import Options.Applicative.Extra (customExecParser, helper, hsubparser)
 import Options.Applicative.Types (Parser)
 
 import System.IO (Handle, hFlush, stderr, hSetBuffering, BufferMode(..))
@@ -234,7 +234,7 @@ main = do
     customExecParser (prefs showHelpOnError) (info (helper <*> versioner <*> cmd homedir) (headerDoc (Just (banner "hkt")) <> progDesc "hOpenPGP Keyring Tool" <> footerDoc (Just (warranty "hkt")))) >>= dispatch
 
 cmd :: String -> Parser Command
-cmd homedir = subparser
+cmd homedir = hsubparser
     ( command "export-pubkeys" (info ( CmdExportPubkeys <$> listO homedir) ( progDesc "export matching keys to stdout" <> footerDoc (Just foot) ))
    <> command "findpaths" (info ( CmdFindPaths <$> findPathsO homedir) ( progDesc "find short paths between keys" <> footerDoc (Just foot) ))
    <> command "graph" (info ( CmdGraph <$> graphO homedir) ( progDesc "graph certifications" <> footerDoc (Just foot) ))
