@@ -69,8 +69,8 @@ import Data.Time.Format (formatTime)
 import qualified Data.Yaml as Y
 import GHC.Generics
 
-import Options.Applicative.Builder (argument, auto, command, eitherReader, footerDoc, headerDoc, help, helpDoc, info, long, metavar, prefs, progDesc, showDefault, showHelpOnError, option, subparser, str, value)
-import Options.Applicative.Extra (customExecParser, helper)
+import Options.Applicative.Builder (argument, auto, command, eitherReader, footerDoc, headerDoc, help, helpDoc, info, long, metavar, prefs, progDesc, showDefault, showHelpOnError, option, str, value)
+import Options.Applicative.Extra (customExecParser, helper, hsubparser)
 import Options.Applicative.Types (Parser)
 
 import System.IO (Handle, hFlush, hPutStrLn, stderr, stdin, stdout, hSetBuffering, BufferMode(..))
@@ -372,7 +372,7 @@ main = do
     customExecParser (prefs showHelpOnError) (info (helper <*> versioner <*> cmd) (headerDoc (Just (banner "hokey")) <> progDesc "hOpenPGP Key utility" <> footerDoc (Just (warranty "hokey")))) >>= dispatch
 
 cmd :: Parser Command
-cmd = subparser
+cmd = hsubparser
     ( command "canonicalize" (info ( pure CmdCanonicalize) ( progDesc "arrange key components in a canonical ordering" ))
    <> command "fetch" (info ( CmdFetch <$> fetchO) ( progDesc "fetch key(s) from keyserver" ))
    <> command "lint" (info ( CmdLint <$> lintO) ( progDesc "check key(s) for 'best practices'" ))
